==> typescript_1.7.5.orig.tar.gz: TypeScript-1.7.5/tests/cases/conformance/expressions/typeGuards/typeGuardOfFormTypeOfOther.ts <==
class C { private p: string };

var str: string;
var bool: boolean;
var num: number;
var strOrNum: string | number;
var strOrBool: string | boolean;
var numOrBool: number | boolean
var strOrNumOrBool: string | number | boolean;
var strOrC: string | C;
var numOrC: number | C;
var boolOrC: boolean | C;
var emptyObj: {};
var c: C;

// A type guard of the form typeof x === s, 
// where s is a string literal with any value but 'string', 'number' or 'boolean',
//  - when true, removes the primitive types string, number, and boolean from the type of x, or
//  - when false, has no effect on the type of x.

if (typeof strOrC === "Object") {
    c = strOrC; // C
}
else {
    var r2: string | C = strOrC; // string | C
}
if (typeof numOrC === "Object") {
    c = numOrC; // C
}
else {
    var r3: number | C = numOrC; // number | C
}
if (typeof boolOrC === "Object") {
    c = boolOrC; // C
}
else {
    var r4: boolean | C = boolOrC; // boolean | C
}

// Narrowing occurs only if target type is a subtype of variable type
if (typeof strOrNumOrBool === "Object") {
    var q1: string | number | boolean = strOrNumOrBool; // string | number | boolean
}
else {
    var q2: string | number | boolean = strOrNumOrBool; // string | number | boolean
}

// A type guard of the form typeof x !== s, where s is a string literal,
//  - when true, narrows the type of x by typeof x === s when false, or
//  - when false, narrows the type of x by typeof x === s when true.
if (typeof strOrC !== "Object") {
    var r2: string | C = strOrC; // string | C
}
else {
    c = strOrC; // C
}
if (typeof numOrC !== "Object") {
    var r3: number | C = numOrC; // number | C
}
else {
    c = numOrC; // C
}
if (typeof boolOrC !== "Object") {
    var r4: boolean | C = boolOrC; // boolean | C
}
else {
    c = boolOrC; // C
}

// Narrowing occurs only if target type is a subtype of variable type
if (typeof strOrNumOrBool !== "Object") {
    var q1: string | number | boolean = strOrNumOrBool; // string | number | boolean
}
else {
    var q2: string | number | boolean = strOrNumOrBool; // string | number | boolean
}

==> typescript_1.8.10.orig.tar.gz: TypeScript-1.8.10/tests/cases/conformance/expressions/typeGuards/typeGuardOfFormTypeOfOther.ts <==
class C { private p: string };

var str: string;
var bool: boolean;
var num: number;
var strOrNum: string | number;
var strOrBool: string | boolean;
var numOrBool: number | boolean
var strOrNumOrBool: string | number | boolean;
var strOrC: string | C;
var numOrC: number | C;
var boolOrC: boolean | C;
var emptyObj: {};
var c: C;

// A type guard of the form typeof x === s, 
// where s is a string literal with any value but 'string', 'number' or 'boolean',
//  - when true, removes the primitive types string, number, and boolean from the type of x, or
//  - when false, has no effect on the type of x.

if (typeof strOrC === "Object") {
    c = strOrC; // C
}
else {
    var r2: string = strOrC; // string
}
if (typeof numOrC === "Object") {
    c = numOrC; // C
}
else {
    var r3: number  = numOrC; // number
}
if (typeof boolOrC === "Object") {
    c = boolOrC; // C
}
else {
    var r4: boolean = boolOrC; // boolean
}

// Narrowing occurs only if target type is a subtype of variable type
if (typeof strOrNumOrBool === "Object") {
    var q1: string | number | boolean = strOrNumOrBool; // string | number | boolean
}
else {
    var q2: string | number | boolean = strOrNumOrBool; // string | number | boolean
}

// A type guard of the form typeof x !== s, where s is a string literal,
//  - when true, narrows the type of x by typeof x === s when false, or
//  - when false, narrows the type of x by typeof x === s when true.
if (typeof strOrC !== "Object") {
    var r2: string = strOrC; // string
}
else {
    c = strOrC; // C
}
if (typeof numOrC !== "Object") {
    var r3: number = numOrC; // number
}
else {
    c = numOrC; // C
}
if (typeof boolOrC !== "Object") {
    var r4: boolean = boolOrC; // boolean
}
else {
    c = boolOrC; // C
}

// Narrowing occurs only if target type is a subtype of variable type
if (typeof strOrNumOrBool !== "Object") {
    var q1: string | number | boolean = strOrNumOrBool; // string | number | boolean
}
else {
    var q2: string | number | boolean = strOrNumOrBool; // string | number | boolean
}
